@@ -19,10 +19,12 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include "xvasprintf.h"
+#include "gettext-more.h"
 #include "reddit_priv.h"
 #include "discuss.h"
+#include "view.h"
+#include "stories.h"
 #include "story.h"
-#include "gettext-more.h"
 
 static error_t 
 parse_opt (int key, char *arg, struct argp_state *state)
@@ -92,6 +94,18 @@ int
 reddit_discuss (struct reddit_state_t *state, struct reddit_discuss_options_t *options)
 {
   int err = 0;
-  printf("Discussing story number %d!\n", options->story_id);
+  struct reddit_story_t *story = 
+    reddit_find_story_with_id (state, options->story_id);
+  if (story)
+    {
+      char *id = story->id;
+      id+=3;
+      char *link = xasprintf("http://%s/r/%s/comments/%s/.compact", 
+                             state->site, story->subreddit, id);
+
+      printf("link is `%s'\n", link);
+      err = reddit_spawn_viewer_for_link (state, link);
+      free (link);
+    }
   return err;
 }
