@@ -23,9 +23,12 @@
 enum app_command_line_options_t
 {
   OPT_PROXY = -211,
+  OPT_NO_SHOW,
+  OPT_COOKIEFILE,
   OPT_HOST = 'h',
   OPT_LOGIN = 'l',
   OPT_QUIET = 'q',
+  OPT_SCRIPT = 's',
   OPT_PASSWORD_WALLET = 'w',
 };
 
