@@ -21,6 +21,7 @@
 #include <argp.h>
 #include <glib.h>
 #include <argz.h>
+#include <string.h>
 #include "story.h"
 #include "stories.h"
 #include "whats.h"
@@ -123,27 +124,42 @@ reddit_load_link_from_story_chunk (struct reddit_state_t *state, gchar *data)
   char *link = NULL;
   gchar **fields;
   if (state->logged_in)
-    fields = g_regex_split_simple ("<a class=\"title loggedin \" href=\"", data, 0, 0);
+    fields = g_regex_split_simple ("<a class=\"title loggedin \" href=\"", 
+                                   data, 0, 0);
   else
     fields = g_regex_split_simple ("<a class=\"title \" href=\"", data, 0, 0);
   int num_fields = g_strv_length (fields);
   if (num_fields <= 1)
     {
       g_strfreev (fields);
-      return NULL;
-    }
-  else
-    {
-      int retval = sscanf (fields[1], "%ms", &link);
-      if (retval != 1)
+      //not there?  that's not so strange.  flip it.  
+      //maybe we're logged in when we thought we were logged out.  
+      //maybe we're logged out when we thought we were logged in.
+      if (state->logged_in)
+        fields = g_regex_split_simple ("<a class=\"title \" href=\"", 
+                                       data, 0, 0);
+      else
+        fields = g_regex_split_simple ("<a class=\"title loggedin \" href=\"", 
+                                       data, 0, 0);
+
+      int num_fields = g_strv_length (fields);
+      if (num_fields <= 1)
         {
           g_strfreev (fields);
           return NULL;
         }
-      char *quote = strchr (link, '\"');
-      if (quote)
-        *quote = '\0';
+      state->logged_in = !state->logged_in;
     }
+
+  int retval = sscanf (fields[1], "%ms", &link);
+  if (retval != 1)
+    {
+      g_strfreev (fields);
+      return NULL;
+    }
+  char *quote = strchr (link, '\"');
+  if (quote)
+    *quote = '\0';
   g_strfreev (fields);
   return link;
 }
@@ -402,8 +418,7 @@ reddit_load_story_from_chunk (struct reddit_state_t *state, gchar *data, int *er
   story.score = reddit_load_score_from_story_chunk (state, data, err);
   if (err && *err)
     {
-      if (err)
-        *err = -102;
+      *err = -102;
       return story;
     }
 
@@ -411,7 +426,7 @@ reddit_load_story_from_chunk (struct reddit_state_t *state, gchar *data, int *er
   if (!link)
     {
       if (err)
-        *err = -102;
+        *err = -103;
       return story;
     }
   story.link = link;
@@ -420,7 +435,7 @@ reddit_load_story_from_chunk (struct reddit_state_t *state, gchar *data, int *er
   if (!title)
     {
       if (err)
-        *err = -103;
+        *err = -104;
       return story;
     }
   story.title = title;
@@ -429,7 +444,7 @@ reddit_load_story_from_chunk (struct reddit_state_t *state, gchar *data, int *er
   if (!provider)
     {
       if (err)
-        *err = -104;
+        *err = -105;
       return story;
     }
   story.provider = provider;
@@ -438,7 +453,7 @@ reddit_load_story_from_chunk (struct reddit_state_t *state, gchar *data, int *er
   if (!ago)
     {
       if (err)
-        *err = -105;
+        *err = -106;
       return story;
     }
   story.ago = ago;
